@@ -49,7 +49,7 @@ __license__ = "GPLv2"
 __maintainer__ = "Michael G. Noll"
 __status__ = "Development"
 __url__ = "http://www.michael-noll.com/"
-__version__ = "1.5.5"
+__version__ = "1.5.6"
 
 import base64
 import cgi
@@ -731,6 +731,11 @@ class DeliciousAPI(object):
                         if not tags:
                             tags = [u"system:unfiled"]
                         # comment / notes
+                        try:
+                            comment = post['n']
+                        except KeyError:
+                            pass
+                        # bookmark creation time
                         try:
                             timestamp = datetime.datetime.strptime(post['dt'], "%Y-%m-%dT%H:%M:%SZ")
                         except KeyError:
